<?php
session_start();
include 'db.php';

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

$user_id = $_SESSION['user_id'];

// Fetch user progress and last claim time
$sql_check_progress = "SELECT `week`, `day`, `last_claim_time` FROM `user_daily_rewards` WHERE `user_id` = ?";
$stmt = $conn->prepare($sql_check_progress);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $progress = $result->fetch_assoc();
    $current_week = $progress['week'];
    $current_day = $progress['day'];
    $last_claim_time = $progress['last_claim_time'];
} else {
    // Default to Week 1, Day 1
    $current_week = 1;
    $current_day = 1;
    $last_claim_time = null;
    $sql_insert_progress = "INSERT INTO `user_daily_rewards` (`user_id`, `week`, `day`, `last_claim_time`) VALUES (?, ?, ?, ?)";
    $stmt = $conn->prepare($sql_insert_progress);
    $stmt->bind_param("iiis", $user_id, $current_week, $current_day, $last_claim_time);
    $stmt->execute();
}

// Check if 24 hours have passed since the last claim
$can_claim = false;
if ($last_claim_time) {
    $time_diff = time() - strtotime($last_claim_time);
    if ($time_diff >= 86400) { // 86400 seconds in a day
        $can_claim = true;
    }
} else {
    $can_claim = true; // Allow claim on the first visit
}

// Handle reward claim
if (isset($_GET['claim']) && $can_claim && isset($_GET['week']) && isset($_GET['day'])) {
    $claimed_week = (int)$_GET['week'];
    $claimed_day = (int)$_GET['day'];

    if ($claimed_week == $current_week && $claimed_day == $current_day) {
        // Define rewards for each day
        $rewards = [100, 300, 500, 1000, 2000, 5000, 20000];
        $reward_amount = $rewards[$claimed_day - 1];

        // Update user coins
        $sql_update_coins = "UPDATE users SET coins = coins + ? WHERE id = ?";
        $stmt = $conn->prepare($sql_update_coins);
        $stmt->bind_param("ii", $reward_amount, $user_id);
        $stmt->execute();

        // Update user progress
        $current_day++;
        if ($current_day > 7) {
            $current_day = 1;
            $current_week++;
        }

        // Update progress and last claim time
        $sql_update_progress = "UPDATE `user_daily_rewards` SET `week` = ?, `day` = ?, `last_claim_time` = NOW() WHERE `user_id` = ?";
        $stmt = $conn->prepare($sql_update_progress);
        $stmt->bind_param("iii", $current_week, $current_day, $user_id);
        $stmt->execute();

        // Redirect to avoid double claim on refresh
        header("Location: daily_reward.php");
        exit();
    } else {
        echo "Invalid claim!";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Daily Reward - Task to Earn</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .reward-card {
            border-radius: 15px;
            border: 1px solid #ddd;
            padding: 20px;
            background-color: #f8f9fa;
            margin-bottom: 20px;
        }
        .reward-box {
            border-radius: 10px;
            border: 1px solid #ddd;
            padding: 10px;
            text-align: center;
            background-color: #fff;
            margin-bottom: 10px;
            font-size: 14px;
            opacity: 0.6;
        }
        .reward-box.active {
            background-color: #007bff;
            color: #fff;
            opacity: 1;
        }
        .reward-box .coin-icon {
            font-size: 24px;
            color: #007bff;
        }
        .reward-box .day-text {
            margin-top: 10px;
        }
        .reward-box .amount-text {
            font-size: 12px;
        }
        .reward-text {
            text-align: center;
            margin-top: 20px;
        }
        .reward-text .card {
            background-color: #e9ecef;
            border-radius: 10px;
            padding: 15px;
            text-align: center;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <h2 class="text-center">Get coins for visiting the daily reward page without skipping</h2>

        <!-- Week Dropdown -->
        <div class="text-center mb-4">
            <select onchange="window.location.href=this.value">
                <?php for ($week = 1; $week <= 4; $week++): ?>
                    <option value="?week=<?php echo $week; ?>" <?php echo ($week == $current_week) ? 'selected' : ''; ?>>
                        Week <?php echo $week; ?>
                    </option>
                <?php endfor; ?>
            </select>
        </div>

        <?php for ($week = 1; $week <= 4; $week++): ?>
            <?php if ($week == $current_week): ?>
                <div class="reward-card">
                    <h5 class="text-center">Week <?php echo $week; ?></h5>
                    <div class="row">
                        <?php for ($day = 1; $day <= 7; $day++): ?>
                            <?php
                            $active_class = ($week == $current_week && $day == $current_day) ? 'active' : '';
                            $coin_amount = 0;
                            if ($week == 1) {
                                $rewards = [100, 300, 500, 1000, 2000, 5000, 20000];
                                $coin_amount = isset($rewards[$day - 1]) ? $rewards[$day - 1] : 0;
                            }
                            ?>
                            <div class="col-4">
                                <div class="reward-box <?php echo $active_class; ?>">
                                    <?php if ($active_class && $can_claim): ?>
                                        <a href="?claim=1&week=<?php echo $week; ?>&day=<?php echo $day; ?>">
                                            <i class="fas fa-coins coin-icon"></i>
                                            <div class="day-text">Day <?php echo $day; ?></div>
                                            <div class="amount-text"><?php echo $coin_amount; ?> Coins</div>
                                            <button class="btn btn-primary">Claim</button>
                                        </a>
                                    <?php else: ?>
                                        <i class="fas fa-coins coin-icon"></i>
                                        <div class="day-text">Day <?php echo $day; ?></div>
                                        <div class="amount-text"><?php echo $coin_amount; ?> Coins</div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        <?php endfor; ?>
                    </div>
                </div>
            <?php endif; ?>
        <?php endfor; ?>

        <div class="reward-text">
            <div class="card">
                Come back after 24hrs to claim your daily rewards!
            </div>
        </div>
    </div>

    <script src="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/js/all.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
 <!-- Footer Navigation Menu -->
 <div class="footer-nav bg-light fixed-bottom">
    <div class="container">
        <div class="row text-center">
            <div class="col-3">
                <a href="dashboard.php" class="nav-link active">
                    <i class="fas fa-home"></i>
                    <span>Dashboard</span>
                </a>
            </div>
            <div class="col-3">
                <a href="tasks.php" class="nav-link">
                    <i class="fas fa-tasks"></i>
                    <span>Tasks</span>
                </a>
            </div>
            <div class="col-3">
                <a href="withdrawals.php" class="nav-link">
                    <i class="fas fa-wallet"></i>
                    <span>Withdraw</span>
                </a>
            </div>
            <div class="col-3">
                <a href="daily_reward.php" class="nav-link">
                    <i class="fas fa-gift"></i>
                    <span class="shorten-text">Daily Reward</span>
                </a>
            </div>
        </div>
    </div>
</div>

<!-- CSS for the Footer Navigation -->
<style>
.footer-nav {
    padding: 10px 0;
    box-shadow: 0 -2px 5px rgba(0, 0, 0, 0.1);
    background: #fff;
    border-top: 1px solid #ddd;
}
.footer-nav .nav-link {
    color: #007bff;
    font-size: 16px;
    display: block;
    text-decoration: none;
    position: relative;
}
.footer-nav .nav-link i {
    display: block;
    font-size: 24px;
    margin-bottom: 5px;
}
.footer-nav .nav-link span {
    display: block;
    font-size: 12px;
}
.footer-nav .nav-link.active {
    color: #0056b3;
    font-weight: bold;
}
.footer-nav .nav-link.active i {
    color: #0056b3;
}
.footer-nav .shorten-text {
    display: inline-block;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    max-width: 80px; /* Adjust this value as needed */
}
</style>
</body>
</html>
